"use strict";
(() => {
  var __defProp = Object.defineProperty;
  var __export = (target, all) => {
    for (var name in all)
      __defProp(target, name, { get: all[name], enumerable: true });
  };

  // src/oklab.ts
  var oklab_exports = {};
  __export(oklab_exports, {
    hex_to_rgb: () => hex_to_rgb,
    new_oklab: () => new_oklab,
    new_rgb: () => new_rgb,
    oklab_to_css_string: () => oklab_to_css_string,
    oklab_to_rgb: () => oklab_to_rgb,
    range: () => range,
    rgb_to_css_string: () => rgb_to_css_string,
    rgb_to_oklab: () => rgb_to_oklab
  });
  function new_rgb() {
    return { r: 0, g: 0, b: 0 };
  }
  function new_oklab() {
    return { L: 0, a: 0, b: 0 };
  }
  function rgb_to_oklab(c, o) {
    if (!o) {
      o = new_oklab();
      rgb_to_oklab(c, o);
      return o;
    }
    const r = gamma_inv(c.r / 255);
    const g = gamma_inv(c.g / 255);
    const b = gamma_inv(c.b / 255);
    const l = Math.cbrt(0.4122214708 * r + 0.5363325363 * g + 0.0514459929 * b);
    const m = Math.cbrt(0.2119034982 * r + 0.6806995451 * g + 0.1073969566 * b);
    const s = Math.cbrt(0.0883024619 * r + 0.2817188376 * g + 0.6299787005 * b);
    o.L = l * 0.2104542553 + m * 0.793617785 + s * -0.0040720468;
    o.a = l * 1.9779984951 + m * -2.428592205 + s * 0.4505937099;
    o.b = l * 0.0259040371 + m * 0.7827717662 + s * -0.808675766;
  }
  function toFractionalRgb(ok, c) {
    const L = ok.L;
    const a = ok.a;
    const b = ok.b;
    const l = (L + 0.3963377774 * a + 0.2158037573 * b) ** 3;
    const m = (L - 0.1055613458 * a - 0.0638541728 * b) ** 3;
    const s = (L - 0.0894841775 * a - 1.291485548 * b) ** 3;
    c.r = 255 * gamma(4.0767416621 * l - 3.3077115913 * m + 0.2309699292 * s);
    c.g = 255 * gamma(-1.2684380046 * l + 2.6097574011 * m - 0.3413193965 * s);
    c.b = 255 * gamma(-0.0041960863 * l - 0.7034186147 * m + 1.707614701 * s);
  }
  function oklab_to_rgb(ok, c) {
    if (!c) {
      c = new_rgb();
      oklab_to_rgb(ok, c);
      return c;
    }
    toFractionalRgb(ok, c);
    normalizeRgb(c);
  }
  function clamp(c) {
    const cc = Math.round(c);
    return cc < 0 ? 0 : cc > 255 ? 255 : cc;
  }
  function normalizeRgb(c) {
    c.r = clamp(c.r);
    c.g = clamp(c.g);
    c.b = clamp(c.b);
  }
  function oklab_to_css_string(ok, alpha) {
    if (typeof alpha != "number")
      return "oklab(".concat(ok.L, " ").concat(ok.a, " ").concat(ok.b, ")");
    if (alpha > 1)
      return "oklab(".concat(ok.L, " ").concat(ok.a, " ").concat(ok.b, " / ").concat(alpha, "%)");
    return "oklab(".concat(ok.L, " ").concat(ok.a, " ").concat(ok.b, " / ").concat(alpha, ")");
  }
  function rgb_to_css_string(c, alpha) {
    if (typeof alpha != "number")
      return "rgb(".concat(c.r, " ").concat(c.g, " ").concat(c.b, ")");
    if (alpha > 1)
      return "rgb(".concat(c.r, " ").concat(c.g, " ").concat(c.b, " / ").concat(alpha, "%)");
    return "rgb(".concat(c.r, " ").concat(c.g, " ").concat(c.b, " / ").concat(alpha, ")");
  }
  function hex_to_rgb(hex, c) {
    if (!c) {
      c = new_rgb();
      hex_to_rgb(hex, c);
      return c;
    }
    c.r = parseInt(hex.slice(1, 3), 16);
    c.g = parseInt(hex.slice(3, 5), 16);
    c.b = parseInt(hex.slice(5, 7), 16);
  }
  var range = {
    L: {
      min: 0,
      max: 0.9999999934735462,
      range: 0.9999999934735462
    },
    a: {
      min: -0.23388757418790818,
      max: 0.27621639742350523,
      range: 0.5101039716114134
    },
    b: {
      min: -0.3115281476783751,
      max: 0.19856975465179516,
      range: 0.5100979023301703
    }
  };
  function gamma(x) {
    return x >= 31308e-7 ? 1.055 * Math.pow(x, 1 / 2.4) - 0.055 : 12.92 * x;
  }
  function gamma_inv(x) {
    return x >= 0.04045 ? Math.pow((x + 0.055) / (1 + 0.055), 2.4) : x / 12.92;
  }

  // src/browser.ts
  window.oklab = oklab_exports;
})();
