export type rgb = {
    r: number;
    g: number;
    b: number;
};
export type oklab = {
    L: number;
    a: number;
    b: number;
};
export declare function new_rgb(): rgb;
export declare function new_oklab(): oklab;
export declare function rgb_to_oklab(c: rgb): oklab;
export declare function rgb_to_oklab(c: rgb, o: oklab): void;
export declare function oklab_to_rgb(ok: oklab): rgb;
export declare function oklab_to_rgb(ok: oklab, c: rgb): void;
/**
 * @example "oklab(0.5 0.2 0.1)"
 * @example "oklab(0.5 0.2 0.1 / 50%)"
 * @example "oklab(0.5 0.2 0.1 / 0.5)"
 */
export declare function oklab_to_css_string(ok: oklab, alpha?: number): string;
/**
 * @example "rgb(20 80 120)"
 * @example "rgb(20 80 120 / 50%)"
 * @example "rgb(20 80 120 / 0.5)"
 */
export declare function rgb_to_css_string(c: rgb, alpha?: number): string;
export declare function hex_to_rgb(hex: string): rgb;
export declare function hex_to_rgb(hex: string, c: rgb): void;
/**
 * Minimum and maximum L, a, and b values
 * (as seen from all the possible conversions from rgb)
 */
export declare const range: {
    L: {
        min: 0;
        max: 0.9999999934735462;
        range: 0.9999999934735462;
    };
    a: {
        min: -0.23388757418790818;
        max: 0.27621639742350523;
        range: 0.5101039716114134;
    };
    b: {
        min: -0.3115281476783751;
        max: 0.19856975465179516;
        range: 0.5100979023301703;
    };
};
